import QtQuick 2.9
import QtQuick.Controls 2.15
import org.kde.plasma.components 2.0
import org.kde.plasma.core 2.1
import QtQuick.Layouts 1.15

//astros mlb scores

Item {
    id:astrosItem
    width:420
    height:125

    function getOrdinal(n) {            // assigns superfix to date
        var s=["th","st","nd","rd"],
        v=n%100;
        return (s[(v-20)%10]||s[v]||s[0]);
    }

    Column {
        Rectangle {
            width:astrosItem.width*.99
            height:65
            antialiasing : true
            color:"transparent"
            border.color:"transparent"
            radius:8

            MouseArea {
                id: mouseArea1a
                anchors.fill: parent
                cursorShape:  Qt.PointingHandCursor
                hoverEnabled:true
                acceptedButtons: Qt.LeftButton | Qt.MiddleButton
                onEntered:parent.border.color=Theme.viewHoverColor
                onExited:parent.border.color="transparent"
                onClicked: Qt.openUrlExternally(jsonData.scores.events[jsonData.key].links[0].href)
                }
            }

        Row {
            id:game
            spacing:10
            topPadding:10
            leftPadding:15
            // total width 420
            // logo1  48
            // team1  45
            // score1 45
            // inning 35
            // spacer 20
            // logo0  48
            // spacer 2
            // team0  55
            // score0 45
            //  343
            // 9 items spacer 10
            // space btw = 9

            Image {
                source:jsonData.scores.events[jsonData.key].competitions[0].competitors[1].team.logo
                width:48
                height:48
                cache:false
                smooth:true
            }
            Text {
                id:awayTeam
                text:jsonData.scores.events[jsonData.key].competitions[0].competitors[1].team.abbreviation
                color:Theme.textColor
                antialiasing : true
                font.pointSize:16
                width:45
                Layout.fillWidth:true

                Text {
                    id:awayTeamRecord
                    text:"("+jsonData.scores.events[jsonData.key].competitions[0].competitors[1].records[0].summary+")"
                    color:"gray"
                    font.pointSize:10
                    antialiasing : true
                    anchors.top:parent.bottom
                    anchors.horizontalCenter:parent.horizontalCenter
                }
            }

            Text {
                id:awayTeamScore
                text:jsonData.scores.events[jsonData.key].competitions[0].competitors[1].score
                color:Theme.textColor
                antialiasing : true
                font.pointSize:16
                width:35
                Layout.fillWidth:true
            }

            Text {
                id:gameStatus
                text:gameState()
                color:Theme.textColor
                antialiasing : true
                font.pointSize:12
                topPadding:5
                width:40
                Layout.fillWidth:true

                Text {
                    id:gameTime
                    text:Qt.formatDateTime(new Date(jsonData.scores.events[jsonData.key].competitions[0].date),"M/dd/yy")
                    color:"gray"
                    antialiasing : true
                    font.pointSize:10
                    anchors.top:parent.bottom
                    anchors.horizontalCenter:parent.horizontalCenter
                }
            }

            Text {
                text:""         //spacer
                width:15
                Layout.fillWidth:true
            }

            Image {
                id:homeTeamLogo
                source:jsonData.scores.events[jsonData.key].competitions[0].competitors[0].team.logo
                width:48
                height:48
                cache:false
                smooth:true
            }

            Text {
                text:""         //spacer
                width:2
                Layout.fillWidth:true
            }
            Text {
                id:homeTeam
                text:jsonData.scores.events[jsonData.key].competitions[0].competitors[0].team.abbreviation
                color:Theme.textColor
                font.pointSize:16
                antialiasing : true
                width:55
                Layout.fillWidth:true

                Text {
                    id:homeTeamRecord
                    text:"("+jsonData.scores.events[jsonData.key].competitions[0].competitors[0].records[0].summary+")"
                    color:"gray"
                    antialiasing : true
                    font.pointSize:10
                    anchors.top:parent.bottom
                    anchors.horizontalCenter:parent.horizontalCenter
                }
            }

            Text {
                id:homeTeamScore
                text:jsonData.scores.events[jsonData.key].competitions[0].competitors[0].score
                color:Theme.textColor
                antialiasing : true
                font.pointSize:16
                width:45
                Layout.fillWidth:true
            }
        }

        Row {
            anchors.top:game.bottom
            topPadding:7

            Text {
                id:gameHeadline
                text:jsonData.scores.events[jsonData.key].competitions[0].hasOwnProperty("headlines") ? jsonData.scores.events[jsonData.key].competitions[0].headlines[0].shortLinkText : ""
                color:Theme.textColor
                font.pointSize:11
                antialiasing : true
                leftPadding:10
                width:astrosItem.width*.95
                Layout.fillWidth: true
                elide: Text.ElideRight
                wrapMode: Text.NoWrap
            }
        }
    }
    function gameState() {
        if (jsonData.scores.events[jsonData.key].competitions[0].status.type.state == "pre") {
            gameStatus.width=55
            return (Qt.formatDateTime(new Date(jsonData.scores.events[jsonData.key].competitions[0].date),"h:mm ap"));
        }
        else if (jsonData.scores.events[jsonData.key].competitions[0].status.type.state == "in") {
            gameStatus.width=35
            return (jsonData.scores.events[jsonData.key].competitions[0].status.period+getOrdinal(jsonData.scores.events[jsonData.key].competitions[0].status.period));
        }
        else {
             jsonData.scores.events[jsonData.key].competitions[0].status.type.detail.length > 5 ? gameStatus.width=45 : gameStatus.width=33
             return (jsonData.scores.events[jsonData.key].competitions[0].status.type.detail);
        }
    }
}
