import QtQuick 2.9
import org.kde.plasma.core 2.1

Item {
    id:scoresMain
    width:420
    height:85


    function getOrdinal(n) {            // assigns superfix to date
        var s=["th","st","nd","rd"],
        v=n%100;
        return (s[(v-20)%10]||s[v]||s[0]);
    }

    function gameState() {
        if (jsonData.scores.events[jsonData.key].competitions[0].status.type.state == "pre") {
            return (Qt.formatDateTime(new Date(jsonData.scores.events[jsonData.key].competitions[0].date),"h:mm ap"));
        }
        else if (jsonData.scores.events[jsonData.key].competitions[0].status.type.state == "in") {
               if (jsonData.scores.events[jsonData.key].competitions[0].status.type.description!="In Progress") {
                     return (jsonData.scores.events[jsonData.key].competitions[0].status.type.detail);
                }
            return (jsonData.scores.events[jsonData.key].competitions[0].status.period+getOrdinal(jsonData.scores.events[jsonData.key].competitions[0].status.period));
        }
        else {
            return (jsonData.scores.events[jsonData.key].competitions[0].status.type.detail);
        }
    }

    function refreshGameData () {
        jsonData.getData(jsonData.url2);
        jsonData.initTimer.start()
    }

    Rectangle {
        id:rect1
        width:scoresMain.width*.99
        height:85
        antialiasing : true
        color:"transparent"
        border.color:"transparent"
        radius:8
        anchors.top:scoresMain.top
        anchors.left:scoresMain.left
        anchors.leftMargin:2

        MouseArea {
            id: mouseArea1a
            anchors.fill: parent
            cursorShape:  Qt.PointingHandCursor
            hoverEnabled:true
            acceptedButtons: Qt.LeftButton | Qt.MiddleButton
            onEntered:parent.border.color=Theme.viewHoverColor
            onExited:parent.border.color="transparent"
            onClicked:(mouse.button==Qt.LeftButton) ? Qt.openUrlExternally(jsonData.scores.events[jsonData.key].links[0].href) : refreshGameData()
        }

        Image{
            id:awayTeamLogo
            source:jsonData.scores.events[jsonData.key].competitions[0].competitors[1].team.logo
            height:48
            width:48
            anchors.left:rect1.left
            anchors.top:rect1.top
            anchors.leftMargin:15
            anchors.rightMargin:15
            anchors.topMargin:10
        }

        Text {
            id:awayTeam
            text:jsonData.scores.events[jsonData.key].competitions[0].competitors[1].team.abbreviation
            color:"white"
            font.pointSize:16
            anchors.topMargin:10
            anchors.leftMargin:15
            anchors.rightMargin:15
            anchors.top:rect1.top
            anchors.left:awayTeamLogo.right

            Text {
                id:awayTeamRecord
                text:"("+jsonData.scores.events[jsonData.key].competitions[0].competitors[1].records[0].summary+")"
                color:"gray"
                font.pointSize:10
                antialiasing : true
                anchors.horizontalCenter:parent
                anchors.top:parent.bottom
            }
        }

        Text {
            id:awayTeamScore
            text:jsonData.scores.events[jsonData.key].competitions[0].competitors[1].score
            color:"white"
            font.pointSize:16
            anchors.topMargin:10
            anchors.top:rect1.top
            anchors.left:awayTeam.right
            anchors.leftMargin:15
        }

        Text {
            text:gameState()
            color:"white"
            anchors.topMargin:15
            anchors.top:rect1.top
            anchors.horizontalCenter:rect1.horizontalCenter

            Text {
                id:gameTime
                text:Qt.formatDateTime(new Date(jsonData.scores.events[jsonData.key].competitions[0].date),"M/dd/yy")
                color:"gray"
                font.pointSize:10
                anchors.top:parent.bottom
                anchors.horizontalCenter:parent.horizontalCenter
            }
        }

        Image{
            id:homeTeamLogo
            source:jsonData.scores.events[jsonData.key].competitions[0].competitors[0].team.logo
            height:48
            width:48
            anchors.right:homeTeam.left
            anchors.top:rect1.top
            anchors.rightMargin:15
            anchors.topMargin:10
        }

        Text {
            id:homeTeam
            text:jsonData.scores.events[jsonData.key].competitions[0].competitors[0].team.abbreviation
            color:"white"
            font.pointSize:16
            anchors.topMargin:10
            anchors.leftMargin:15
            anchors.rightMargin:15
            anchors.top:rect1.top
            anchors.right:homeTeamScore.left

            Text {
                id:homeTeamRecord
                text:"("+jsonData.scores.events[jsonData.key].competitions[0].competitors[0].records[0].summary+")"
                color:"gray"
                font.pointSize:10
                anchors.top:parent.bottom
                anchors.horizontalCenter:parent.horizontalCenter
            }
        }

        Text {
            id:homeTeamScore
            text:jsonData.scores.events[jsonData.key].competitions[0].competitors[0].score
            color:"white"
            font.pointSize:16
            anchors.topMargin:10
            anchors.leftMargin:15
            anchors.rightMargin:15
            anchors.top:rect1.top
            anchors.right:rect1.right
        }

        Text {
            id:gameHeadline
            anchors.bottom:rect1.bottom
            anchors.left:rect1.left
            anchors.bottomMargin:2
            text:jsonData.scores.events[jsonData.key].competitions[0].hasOwnProperty("headlines") ? jsonData.scores.events[jsonData.key].competitions[0].headlines[0].shortLinkText : ""
            color:Theme.textColor
            font.pointSize:11
            antialiasing : true
            leftPadding:5
            width:rect1.width*.97
            elide: Text.ElideRight
            wrapMode: Text.NoWrap
        }
    }
}
